@@ -42,6 +42,10 @@ BLOCK_SEPARATOR = r"\n\s*---\s*\n"
 PRESERVE_FENCE_PATTERN = r"^!={3,}\s*$"
 COMPILED_PRESERVE_FENCE_REGEX = re.compile(PRESERVE_FENCE_PATTERN)
 
+# Inline preserved content pattern: ===content=== format
+INLINE_PRESERVE_PATTERN = r"^===(.+)=== *$"
+COMPILED_INLINE_PRESERVE_REGEX = re.compile(INLINE_PRESERVE_PATTERN)
+
 # Output instruction markers
 OUTPUT_INSTRUCTION_PREFIX = "[输出]"
 OUTPUT_INSTRUCTION_SUFFIX = "[/输出]"
@@ -149,7 +153,7 @@ INPUT_EMPTY_ERROR = "输入不能为空"
 
 # System error messages
 UNSUPPORTED_PROMPT_TYPE_ERROR = "不支持的提示词类型: {prompt_type}"
-BLOCK_INDEX_OUT_OF_RANGE_ERROR = "块索引 {index} 超出范围，总共有 {total} 个块"
+BLOCK_INDEX_OUT_OF_RANGE_ERROR = "Block index {index} is out of range; total={total}"
 LLM_PROVIDER_REQUIRED_ERROR = "需要设置 LLMProvider 才能调用 LLM"
 INTERACTION_PARSE_ERROR = "交互格式解析失败: {error}"
 
