@@ -478,7 +478,7 @@ class MarkdownFlow:
             error_msg = f"Please select from: {', '.join(button_displays)}"
             return self._render_error(error_msg, mode)
 
-        # Validate input values against available buttons
+        # First, check if user input matches available buttons
         valid_values = []
         invalid_values = []
 
@@ -491,19 +491,30 @@ class MarkdownFlow:
                     break
 
             if not matched:
-                if allow_text_input:
-                    # Allow custom text in buttons+text mode - same as normal interactions
-                    valid_values.append(value)
-                else:
-                    invalid_values.append(value)
+                invalid_values.append(value)
 
-        # Check for validation errors
-        if invalid_values and not allow_text_input:
+        # If there are invalid values and this interaction allows text input, use LLM validation
+        if invalid_values and allow_text_input:
+            # Use LLM validation for text input interactions
+            button_displays = [btn["display"] for btn in buttons]
+            question = parse_result.get("question", "")
+
+            return self._process_llm_validation_with_options(
+                block_index=0,  # Not used in the method
+                user_input={target_variable: target_values},
+                target_variable=target_variable,
+                options=button_displays,
+                question=question,
+                mode=mode,
+            )
+
+        # Check for validation errors in pure button mode or when text input not allowed
+        if invalid_values:
             button_displays = [btn["display"] for btn in buttons]
             error_msg = f"Invalid options: {', '.join(invalid_values)}. Please select from: {', '.join(button_displays)}"
             return self._render_error(error_msg, mode)
 
-        # Success: return validated values
+        # Success: return validated button values
         return LLMResult(
             content="",
             variables={target_variable: valid_values},
@@ -513,6 +524,7 @@ class MarkdownFlow:
                 "valid_values": valid_values,
                 "invalid_values": invalid_values,
                 "total_input_count": len(target_values),
+                "llm_validated": False,
             },
         )
 
@@ -815,7 +827,14 @@ Original Error: {error_message}
         if match:
             prefix = match.group(1)
             suffix = match.group(2)
-            return f"{prefix}{cleaned_question}{suffix}"
+            # Extract only the closing bracket from suffix, remove original question
+            # suffix format is "original_question]", we only want "]"
+            if suffix.endswith("]"):
+                clean_suffix = "]"
+            else:
+                clean_suffix = suffix
+
+            return f"{prefix}{cleaned_question}{clean_suffix}"
         return original_content  # type: ignore[unreachable]
 
     # Dynamic Interaction Methods
@@ -909,9 +928,9 @@ Original Error: {error_message}
 Task: Analyze the given content block and determine if it needs to be converted to an interaction block to collect user information.
 
 Judgment criteria:
-1. Does the content imply the need to ask users for information?
-2. Does it need to collect detailed information based on previous variable values?
-3. Does it mention "recording" or "saving" information to variables?
+1. It requires to generate/show buttons
+2. It requires to generate/show checkboxs or multi-selection interactive elements
+3. It requires to generate/show text input box
 
 If conversion is needed, generate a STANDARD interaction block format with SPECIFIC options based on the document-level instructions and context provided in the user message."""
 
@@ -1111,9 +1130,8 @@ Analyze the content and provide the structured interaction data.""")
                         "empty_input": True,
                     },
                 )
-            else:
-                error_msg = f"No input provided for variable '{variable_name}'"
-                return self._render_error(error_msg, mode)
+            error_msg = f"No input provided for variable '{variable_name}'"
+            return self._render_error(error_msg, mode)
 
         # Use the same validation logic as normal interactions
         if interaction_type in [
@@ -1132,7 +1150,7 @@ Analyze the content and provide the structured interaction data.""")
             )
 
             # Merge with existing variables for dynamic interactions
-            if hasattr(button_result, 'variables') and button_result.variables is not None and variables:
+            if hasattr(button_result, "variables") and button_result.variables is not None and variables:
                 merged_variables = dict(variables)
                 merged_variables.update(button_result.variables)
                 return LLMResult(
@@ -1142,7 +1160,7 @@ Analyze the content and provide the structured interaction data.""")
                 )
             return button_result
 
-        elif interaction_type == InteractionType.NON_ASSIGNMENT_BUTTON:
+        if interaction_type == InteractionType.NON_ASSIGNMENT_BUTTON:
             # Non-assignment buttons: don't set variables, keep existing ones
             return LLMResult(
                 content="",
@@ -1152,16 +1170,15 @@ Analyze the content and provide the structured interaction data.""")
                     "user_input": user_input,
                 },
             )
-        else:
-            # Text-only input type - merge with existing variables
-            merged_variables = dict(variables or {})
-            merged_variables[variable_name] = target_values
-            return LLMResult(
-                content="",
-                variables=merged_variables,
-                metadata={
-                    "interaction_type": "text_only",
-                    "target_variable": variable_name,
-                    "values": target_values,
-                },
-            )
+        # Text-only input type - merge with existing variables
+        merged_variables = dict(variables or {})
+        merged_variables[variable_name] = target_values
+        return LLMResult(
+            content="",
+            variables=merged_variables,
+            metadata={
+                "interaction_type": "text_only",
+                "target_variable": variable_name,
+                "values": target_values,
+            },
+        )
