@@ -77,36 +77,30 @@ def test_chinese_restaurant_scenario():
 
             # 第三步：测试无效选择
             print("\n--- 测试无效选择 ---")
-            try:
-                invalid_choices = ["意大利面", "汉堡包"]  # 不在选项中的选择
-                result3 = mf.process(
-                    block_index=0,
-                    mode=ProcessMode.COMPLETE,
-                    user_input={"菜品选择": invalid_choices},
-                    dynamic_interaction_format=result1.content
-                )
-                if hasattr(result3, 'content') and result3.content and "Invalid" in result3.content:
-                    print("✅ 正确处理无效选择")
-                else:
-                    print("⚠️ 可能允许了无效选择")
-            except Exception as e:
-                print(f"✅ 正确拒绝无效选择: {str(e)[:50]}...")
+            invalid_choices = ["意大利面", "汉堡包"]  # 不在选项中的选择
+            result3 = mf.process(
+                block_index=0,
+                mode=ProcessMode.COMPLETE,
+                user_input={"菜品选择": invalid_choices},
+                dynamic_interaction_format=result1.content
+            )
+            print(f"无效选择输入: {invalid_choices}")
+            print(f"LLM完整响应: {result3.content}")
+            print(f"返回变量: {result3.variables}")
+            print(f"元数据: {result3.metadata}")
 
             # 第四步：测试空输入
             print("\n--- 测试空输入 ---")
-            try:
-                result4 = mf.process(
-                    block_index=0,
-                    mode=ProcessMode.COMPLETE,
-                    user_input={"菜品选择": []},
-                    dynamic_interaction_format=result1.content
-                )
-                if hasattr(result4, 'content') and result4.content:
-                    print("⚠️ 空输入可能被接受（取决于交互类型）")
-                else:
-                    print("✅ 正确处理空输入")
-            except Exception as e:
-                print(f"✅ 正确处理空输入错误: {str(e)[:50]}...")
+            result4 = mf.process(
+                block_index=0,
+                mode=ProcessMode.COMPLETE,
+                user_input={"菜品选择": []},
+                dynamic_interaction_format=result1.content
+            )
+            print(f"空输入: []")
+            print(f"LLM完整响应: {result4.content}")
+            print(f"返回变量: {result4.variables}")
+            print(f"元数据: {result4.metadata}")
 
             print("✅ 中文餐厅场景完整验证通过")
 
@@ -176,18 +170,17 @@ Format: Provide specific educational options"""
 
             # 第三步：测试部分匹配选择
             print("\n--- Test Partial Match ---")
-            try:
-                partial_choices = ["Computer"]  # 只选择一个词
-                result3 = mf.process(
-                    block_index=0,
-                    mode=ProcessMode.COMPLETE,
-                    user_input={"learning_choice": partial_choices},
-                    dynamic_interaction_format=result1.content
-                )
-                print(f"Partial selection: {partial_choices}")
-                print(f"Result: {result3.variables}")
-            except Exception as e:
-                print(f"Partial selection handling: {str(e)[:50]}...")
+            partial_choices = ["Computer"]  # 只选择一个词
+            result3 = mf.process(
+                block_index=0,
+                mode=ProcessMode.COMPLETE,
+                user_input={"learning_choice": partial_choices},
+                dynamic_interaction_format=result1.content
+            )
+            print(f"部分匹配输入: {partial_choices}")
+            print(f"LLM完整响应: {result3.content}")
+            print(f"返回变量: {result3.variables}")
+            print(f"元数据: {result3.metadata}")
 
             # 第四步：测试单个选择
             print("\n--- Test Single Selection ---")
@@ -414,20 +407,18 @@ def test_complex_job_consultation_scenario():
 
             # 测试无效职位选择
             print("\n--- 测试无效职位选择 ---")
-            try:
-                invalid_job = ["厨师", "司机"]  # 不属于科技行业的职位
-                result_invalid = mf.process(
-                    block_index=1,
-                    mode=ProcessMode.COMPLETE,
-                    variables=result1.variables,
-                    user_input={"职位选择": invalid_job},
-                    dynamic_interaction_format=result2.content
-                )
-                print("⚠️ 无效职位选择可能被接受")
-                # 避免未使用变量警告
-                _ = result_invalid
-            except Exception as e:
-                print(f"✅ 正确拒绝无效职位选择: {str(e)[:50]}...")
+            invalid_job = ["厨师", "司机"]  # 不属于科技行业的职位
+            result_invalid = mf.process(
+                block_index=1,
+                mode=ProcessMode.COMPLETE,
+                variables=result1.variables,
+                user_input={"职位选择": invalid_job},
+                dynamic_interaction_format=result2.content
+            )
+            print(f"无效职位输入: {invalid_job}")
+            print(f"LLM完整响应: {result_invalid.content}")
+            print(f"返回变量: {result_invalid.variables}")
+            print(f"元数据: {result_invalid.metadata}")
 
             # 第四步：生成薪资选项
             print("\n--- 步骤4: 生成薪资选项 ---")
@@ -567,16 +558,16 @@ def test_text_input_scenario():
 
             # 测试空输入（对于支持文本输入的交互，可能允许空输入）
             print("\n--- 测试空输入处理 ---")
-            try:
-                result5 = mf.process(
-                    block_index=0,
-                    mode=ProcessMode.COMPLETE,
-                    user_input={"自定义需求": []},
-                    dynamic_interaction_format=result1.content
-                )
-                print("✅ 空输入被接受（支持文本输入的交互可能允许空输入）")
-            except Exception as e:
-                print(f"空输入被拒绝: {str(e)[:50]}...")
+            result5 = mf.process(
+                block_index=0,
+                mode=ProcessMode.COMPLETE,
+                user_input={"自定义需求": []},
+                dynamic_interaction_format=result1.content
+            )
+            print(f"空输入: []")
+            print(f"LLM完整响应: {result5.content}")
+            print(f"返回变量: {result5.variables}")
+            print(f"元数据: {result5.metadata}")
 
             print("✅ 文本输入场景完整验证通过")
 
@@ -701,20 +692,18 @@ def test_variable_context_cuisine_scenario():
 
             # 测试无效菜品选择
             print("\n--- 测试无效菜品选择 ---")
-            try:
-                invalid_dishes = ["北京烤鸭", "小笼包"]  # 非川菜选项
-                result_invalid = mf.process(
-                    block_index=1,
-                    mode=ProcessMode.COMPLETE,
-                    variables=result1.variables,
-                    user_input={"菜品": invalid_dishes},
-                    dynamic_interaction_format=result2.content
-                )
-                print("⚠️ 无效菜品选择可能被接受")
-                # 避免未使用变量警告
-                _ = result_invalid
-            except Exception as e:
-                print(f"✅ 正确拒绝无效菜品选择: {str(e)[:50]}...")
+            invalid_dishes = ["北京烤鸭", "小笼包"]  # 非川菜选项
+            result_invalid = mf.process(
+                block_index=1,
+                mode=ProcessMode.COMPLETE,
+                variables=result1.variables,
+                user_input={"菜品": invalid_dishes},
+                dynamic_interaction_format=result2.content
+            )
+            print(f"无效菜品输入: {invalid_dishes}")
+            print(f"LLM完整响应: {result_invalid.content}")
+            print(f"返回变量: {result_invalid.variables}")
+            print(f"元数据: {result_invalid.metadata}")
 
             print("✅ 变量上下文场景完整验证通过")
 
@@ -874,13 +863,11 @@ def test_user_question_text_input():
             print(f"用户疑问输入: {question_input}")
             print(f"验证结果: {result2.variables}")
 
-            # 验证疑问输入的处理
-            result_value = result2.variables.get("风格选择")
-            if result_value == question_input or result_value == question_input[0]:
-                print("✅ 疑问式文本输入被接受（后续需LLM处理语义）")
-                print("📝 注意：语义验证应由LLM负责，固定代码只做格式验证")
-            else:
-                print(f"⚠️ 输入处理结果不符合预期: {result_value}")
+            # 显示疑问输入的完整处理结果
+            print(f"疑问输入: {question_input}")
+            print(f"LLM完整响应: {result2.content}")
+            print(f"返回变量: {result2.variables}")
+            print(f"元数据: {result2.metadata}")
 
             # 测试其他类型的自定义输入
             print("\n--- 测试其他自定义输入 ---")
@@ -891,16 +878,16 @@ def test_user_question_text_input():
             ]
 
             for custom_input in custom_inputs:
-                try:
-                    result_custom = mf.process(
-                        block_index=0,
-                        mode=ProcessMode.COMPLETE,
-                        user_input={"风格选择": custom_input},
-                        dynamic_interaction_format=result1.content
-                    )
-                    print(f"自定义输入 '{custom_input[0]}' - 结果: {result_custom.variables.get('风格选择')}")
-                except Exception as e:
-                    print(f"自定义输入 '{custom_input[0]}' - 错误: {str(e)[:50]}...")
+                result_custom = mf.process(
+                    block_index=0,
+                    mode=ProcessMode.COMPLETE,
+                    user_input={"风格选择": custom_input},
+                    dynamic_interaction_format=result1.content
+                )
+                print(f"\n自定义输入: {custom_input}")
+                print(f"LLM完整响应: {result_custom.content}")
+                print(f"返回变量: {result_custom.variables}")
+                print(f"元数据: {result_custom.metadata}")
 
             print("✅ 用户疑问文本输入场景测试完成")
 
@@ -921,7 +908,8 @@ def run_all_tests():
         test_complex_job_consultation_scenario,
         test_text_input_scenario,
         test_variable_context_cuisine_scenario,
-        test_variable_context_skill_project_scenario
+        test_variable_context_skill_project_scenario,
+        test_user_question_text_input
     ]
 
     for test_func in tests:
